@@ -91,9 +91,11 @@ setClass(
 setMethod(
   "show", "AthenaConnection",
   function(object){
-    cat("AthenaConnection \n")
-  }
-)
+    cat("<AthenaConnection>\n")
+    if (!dbIsValid(object)) {
+      cat("  DISCONNECTED\n")
+    }
+})
 
 #' Disconnect (close) an Athena connection
 #' 
@@ -130,7 +132,7 @@ setMethod(
       on_connection_closed(conn)
       rm(list = ls(all.names = TRUE, envir = conn@ptr), envir = conn@ptr)}
     invisible(NULL)
-  })
+})
 
 #' Is this DBMS object still valid?
 #' 
@@ -174,9 +176,7 @@ setMethod(
   "dbIsValid", "AthenaConnection",
   function(dbObj, ...){
     resource_active(dbObj)
-  }
-)
-
+})
 
 #' Execute a query on Athena
 #' 
@@ -220,8 +220,7 @@ setMethod(
     res <- AthenaResult(
       conn=conn, statement= statement, s3_staging_dir = s3_staging_dir)
     return(res)
-  }
-)
+})
 
 #' @rdname Query
 #' @export
@@ -234,8 +233,7 @@ setMethod(
     res <- AthenaResult(
       conn =conn, statement= statement, s3_staging_dir = s3_staging_dir)
     return(res)
-  }
-)
+})
 
 #' @rdname Query
 #' @export
@@ -258,8 +256,7 @@ setMethod(
       cache_query(res)
     
     return(res)
-  }
-)
+})
 
 #' Determine SQL data type of object
 #' 
@@ -386,8 +383,7 @@ setMethod(
         function(y) y$Name,
         FUN.VALUE = character(1))
     )
-  }
-)
+})
 
 #' List Athena Schema, Tables and Table Types
 #'
@@ -436,7 +432,7 @@ setMethod(
     output <- rbindlist(unlist(output, recursive = FALSE), use.names = TRUE)
     setnames(output, new = c("Schema", "TableName", "TableType"))
     return(output)
-  })
+})
 
 #' List Field names of Athena table
 #'
@@ -545,7 +541,7 @@ setMethod(
     if (inherits(resp, "error") && !grepl(".*table.*not.*found.*", resp, ignore.case = T)) stop(resp)
     
     !grepl(".*table.*not.*found.*", resp[1], ignore.case = T)
-  })
+})
 
 #' Remove table from Athena
 #' 
@@ -637,7 +633,7 @@ setMethod(
     if(!delete_data) message("Info: Only Athena table has been removed.")
     on_connection_updated(conn, ll[["table"]])
     invisible(TRUE)
-  })
+})
 
 #' Send query, retrieve results and then clear result set
 #'
@@ -678,11 +674,11 @@ setMethod(
     con_error_msg(conn, msg = "Connection already closed.")
     stopifnot(is.logical(statistics))
     rs <- dbSendQuery(conn, statement = statement)
-    on.exit(dbClearResult(rs))
     if(statistics) print(dbStatistics(rs))
-    dbFetch(res = rs, n = -1, ...)
-  })
-
+    out <- dbFetch(res = rs, n = -1, ...)
+    dbClearResult(rs)
+    return(out)
+})
 
 #' Get DBMS metadata
 #' 
@@ -728,7 +724,7 @@ setMethod(
     noctua <- as.character(packageVersion("noctua"))
     info <- c(info, paws = paws, noctua = noctua)
     return(info)
-  })
+})
 
 #' Athena table partitions
 #' 
@@ -847,8 +843,7 @@ setMethod(
     con_error_msg(conn, msg = "Connection already closed.")
     ll <- db_detect(conn, name)
     SQL(paste0(dbGetQuery(conn, paste0("SHOW CREATE TABLE ", ll[["dbms.name"]],".",ll[["table"]]))[[1]], collapse = "\n"))
-  })
-
+})
 
 #' Simple wrapper to convert Athena backend file types
 #' 
