@@ -1,3 +1,9 @@
+format_athena_types <- function(athena_types){
+  data_type <- tolower(vapply(athena_types, function(x) x$Type, FUN.VALUE = character(1)))
+  names(data_type) <- vapply(athena_types, function(x) x$Name, FUN.VALUE = character(1))
+  return(data_type)
+}
+
 # ==========================================================================
 # read in method
 athena_read <- function(method, File, athena_types, ...) {
@@ -6,27 +12,49 @@ athena_read <- function(method, File, athena_types, ...) {
 
 athena_read.athena_data.table <-
   function(method, File, athena_types , ...){
-    Type2 <- Type <- AthenaToRDataType(method, athena_types)
+    data_type <- format_athena_types(athena_types)
+    
+    Type2 <- Type <- AthenaToRDataType(method, data_type)
     # Type2 is to handle issue with data.table fread 
     Type2[Type2 %in% "POSIXct"] <- "character"
     
+    fill <- any(c("array", "row", "map", "json") %in% data_type)
+    
     # currently parameter data.table is left as default. If users require data.frame to be returned then parameter will be updated
-    output <- data.table::fread(File, col.names = names(Type2), colClasses = unname(Type2), sep = ",", showProgress = F, na.strings="")
+    output <- data.table::fread(File, col.names = names(Type2), colClasses = unname(Type2), sep = ",", showProgress = F, na.strings="", fill = fill)
     # formatting POSIXct: from string to POSIXct
     for (col in names(Type[Type %in% "POSIXct"])) set(output, j=col, value=as.POSIXct(output[[col]]))
     # AWS Athena returns " values as "". Due to this "" will be reformatted back to "
     for (col in names(Type[Type %in% "character"])) set(output, j=col, value=gsub('""' , '"', output[[col]]))
     
+    # convert raw
+    if(!identical(athena_option_env$binary, "character"))
+      raw_parser(output, data_type)
+    
+    # convert json
+    if(!identical(athena_option_env$json, "character"))
+      json_parser(output, data_type)
+    
     return(output)
   }
 
 athena_read.athena_vroom <- 
   function(method, File, athena_types, ...){
+    data_type <- format_athena_types(athena_types)
+    
     vroom <- pkg_method("vroom", "vroom")
-    Type <- AthenaToRDataType(method, athena_types)
+    Type <- AthenaToRDataType(method, data_type)
 
     output <- vroom(File, delim = ",", col_types = Type, progress = FALSE, trim_ws = FALSE, altrep = TRUE)
-
+    
+    # convert raw
+    if(!identical(athena_option_env$binary, "character"))
+      raw_parser(output, data_type)
+    
+    # convert json
+    if(!identical(athena_option_env$json, "character"))
+      json_parser(output, data_type)
+    
     return(output)
   }
 
@@ -38,7 +66,9 @@ athena_read_lines <- function(method, File, athena_types, ...) {
 # Keep data.table formatting
 athena_read_lines.athena_data.table <-
   function(method, File, athena_types, ...){
-    Type2 <- Type <- AthenaToRDataType(method, athena_types)
+    data_type <- format_athena_types(athena_types)
+    
+    Type2 <- Type <- AthenaToRDataType(method, data_type)
     # Type2 is to handle issue with data.table fread 
     Type2[Type2 %in% "POSIXct"] <- "character"
     
@@ -49,17 +79,35 @@ athena_read_lines.athena_data.table <-
     # AWS Athena returns " values as "". Due to this "" will be reformatted back to "
     for (col in names(Type[Type %in% "character"])) set(output, j=col, value=gsub('""' , '"', output[[col]]))
     
+    # convert raw
+    if(!identical(athena_option_env$binary, "character"))
+      raw_parser(output, data_type)
+    
+    # convert json
+    if(!identical(athena_option_env$json, "character"))
+      json_parser(output, data_type)
+    
     return(output)
   }
 
 athena_read_lines.athena_vroom <- 
   function(method, File, athena_types, ...){
+    data_type <- format_athena_types(athena_types)
+    
     vroom <- pkg_method("vroom", "vroom")
     
-    Type <- AthenaToRDataType(method, athena_types)
+    Type <- AthenaToRDataType(method, data_type)
     
     output <- vroom(File, col_names = names(Type), col_types = unname(Type), progress = FALSE, altrep = TRUE, trim_ws = FALSE, delim = "\n")
     
+    # convert raw
+    if(!identical(athena_option_env$binary, "character"))
+      raw_parser(output, data_type)
+    
+    # convert json
+    if(!identical(athena_option_env$json, "character"))
+      json_parser(output, data_type)
+    
     return(output)
   }
 
